import { BasicColumn, FormSchema } from '@/components/Table';

/** 列表筛选项*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
  {
    field: 'path',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    ifShow: false,
  },
  {
    field: 'policyState',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '策略状态',
      options: [
        { label: '开', value: '开' },
        { label: '关', value: '关' },
      ],
    },
  },
  {
    field: 'sensitiveState',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感状态',
      options: [
        { label: '敏感', value: '敏感' },
        { label: '非敏感', value: '非敏感' },
      ],
    },
  },
];

/** 列表展示字段*/
export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '策略状态',
    dataIndex: 'policyState',
    width: 180,
  },
  {
    title: '敏感状态',
    dataIndex: 'sensitiveState',
    width: 180,
  },
  {
    title: '最近识别时间',
    dataIndex: 'recentRecognitionTime',
    width: 180,
  },
];
export const columnsTable1: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    edit: true,
    editable: true,
  },
];
export const columnsTable2: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    edit: true,
    editable: true,
  },
];
export const columnsTable3: BasicColumn[] = [
  {
    title: '规则名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '敏感类型',
    dataIndex: 'sensitiveType',
    width: 180,
  },
  {
    title: '安全分级',
    dataIndex: 'level',
    width: 180,
  },
];

/** 新增编辑表单字段*/
export const formSchema: any[] = [
  {
    field: 'policyState',
    label: '策略状态',
    component: 'RadioGroup',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '策略状态',
      defaultValue: '关',
      options: [
        { label: '开', value: '开' },
        { label: '关', value: '关' },
      ],
    },
  },
  {
    field: 'fieldRange',
    label: '字段范围',
    component: 'BasicTitle',
    // colProps: { offset: 1 },
    componentProps: {
      style: {
        fontsize: 16,
        fontWeight: 'bold',
        marginLeft: '25px',
      },
    },
  },
  {
    field: 'requestParametersTitle',
    label: '请求参数',
    component: 'Input',
    colProps: { lg: 2, md: 2 },
    componentProps: {
      readonly: true,
      allowClear: false,
      placeholder: ' ',
      style: {
        cursor: 'default',
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
  {
    field: 'requestParametersScannerRange',
    label: '扫描状态',
    component: 'Select',
    colProps: { lg: 4, md: 4 },
    componentProps: {
      placeholder: '扫描状态',
      defaultValue: '全部不扫描',
      options: [
        { label: '全部扫描', value: '全部扫描' },
        { label: '全部不扫描', value: '全部不扫描' },
      ],
    },
  },
  {
    field: 'requestParameters',
    component: 'Slot',
    label: ' ',
    labelWidth: 20,
    slot: 'requestParameters',
  },
  {
    field: 'returnParameterTitle',
    label: '返回参数',
    component: 'Input',
    colProps: { lg: 2, md: 2 },
    componentProps: {
      readonly: true,
      allowClear: false,
      placeholder: ' ',
      style: {
        cursor: 'default',
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
  {
    field: 'returnParameterScannerRange',
    label: '扫描状态',
    component: 'Select',
    colProps: { lg: 4, md: 4 },
    componentProps: {
      placeholder: '扫描状态',
      defaultValue: '全部扫描',
      options: [
        { label: '全部扫描', value: '全部扫描' },
        { label: '全部不扫描', value: '全部不扫描' },
      ],
    },
  },
  {
    field: 'returnParameter',
    label: ' ',
    labelWidth: 20,
    component: 'Slot',
    slot: 'returnParameter',
  },
  {
    field: 'sensitiveRulesTitle',
    label: '敏感规则',
    component: 'BasicTitle',
    // colProps: { offset: 1 },
    componentProps: {
      style: {
        fontsize: 16,
        fontWeight: 'bold',
        marginLeft: '25px',
      },
    },
  },
  {
    field: 'sensitiveRules',
    component: 'Slot',
    label: ' ',
    labelWidth: 16,
    slot: 'sensitiveRules',
  },
];

export const rulerFormSchema1: any[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    colProps: { span: 9 },
    componentProps: {
      placeholder: '输入规则',
    },
  },
  {
    field: 'slot',
    label: '',
    slot: 'slot',
  },
];
export const rulerFormSchema2: any[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    colProps: { span: 9 },
    componentProps: {
      placeholder: '输入规则',
    },
  },
];

/** 新增编辑表单字段*/
export const executionFormSchema: any[] = [
  {
    field: 'executionDate',
    label: '执行时间',
    colProps: { lg: 5, md: 5 },
    component: 'DatePicker',
  },
  {
    field: 'sensitiveState',
    label: '敏感状态',
    component: 'Select',
    colProps: { lg: 6, md: 6 },
    componentProps: {
      placeholder: '敏感状态',
      options: [
        { label: '全部', value: '' },
        { label: '敏感', value: '敏感' },
        { label: '非敏感', value: '非敏感' },
      ],
    },
  },
];

export const executionColumns: BasicColumn[] = [
  {
    title: '执行记录',
    dataIndex: 'name',
    width: 120,
  },
];
